==> fvtt-les-heritiers-10.0.2.tar.gz: fvtt-les-heritiers/modules/heritiers-actor-sheet.js <==
/**
 * Extend the basic ActorSheet with some very simple modifications
 * @extends {ActorSheet}
 */

import { HeritiersUtility } from "./heritiers-utility.js";
import { HeritiersAutomation } from "./heritiers-automation.js";

/* -------------------------------------------- */
export class HeritiersActorSheet extends ActorSheet {

  /** @override */
  static get defaultOptions() {

    return mergeObject(super.defaultOptions, {
      classes: ["fvtt-les-heritiers", "sheet", "actor"],
      template: "systems/fvtt-les-heritiers/templates/actor-sheet.html",
      width: 640,
      height: 720,
      tabs: [{ navSelector: ".sheet-tabs", contentSelector: ".sheet-body", initial: "stats" }],
      dragDrop: [{ dragSelector: ".item-list .item", dropSelector: null }],
      editScore: false
    })
  }

  /* -------------------------------------------- */
  async getData() {
    const objectData = duplicate(this.object)    

    let formData = {
      title: this.title,
      id: objectData.id,
      type: objectData.type,
      img: objectData.img,
      name: objectData.name,
      editable: this.isEditable,
      cssClass: this.isEditable ? "editable" : "locked",
      system: objectData.system,
      effects: this.object.effects.map(e => foundry.utils.deepClone(e.data)),
      limited: this.object.limited,
      skills: this.actor.getSkills(),
      armes: duplicate(this.actor.getWeapons()),
      monnaies: duplicate(this.actor.getMonnaies()),
      protections: duplicate(this.actor.getArmors()),
      historiques: duplicate(this.actor.getHistoriques() || []),
      talents: duplicate(this.actor.getTalents() || []),
      talentsCell: this.getCelluleTalents(),
      profils: duplicate(this.actor.getProfils()  || []),
      combat: this.actor.getCombatValues(),      
      equipements: duplicate(this.actor.getEquipments()),
      artefacts: duplicate(this.actor.getArtefacts()),
      monnaies: duplicate(this.actor.getMonnaies()),
      richesse: this.actor.computeRichesse(),
      valeurEquipement: this.actor.computeValeurEquipement(),
      initiative: this.actor.getFlag("world", "last-initiative") || -1,
      description: await TextEditor.enrichHTML(this.object.system.biodata.description, {async: true}),
      habitat: await TextEditor.enrichHTML(this.object.system.biodata.habitat, {async: true}),
      options: this.options,
      owner: this.document.isOwner,
      editScore: this.options.editScore,
      isGM: game.user.isGM
    }
    this.formData = formData;

    console.log("PC : ", formData, this.object);
    return formData;
  }

  /* -------------------------------------------- */
  getCelluleTalents( )  {
    let talents = []
    for(let cellule of game.actors) {
      if (cellule.type == "cellule") {
        let found = cellule.system.members.find( it => it.id == this.actor.id)
        if (found) {
          talents = talents.concat( cellule.getTalents() )
        }
      }
    }
    return talents
  }

  /* -------------------------------------------- */
  /** @override */
  activateListeners(html) {
    super.activateListeners(html);

    // Everything below here is only needed if the sheet is editable
    if (!this.options.editable) return;
    
    // Update Inventory Item
    html.find('.item-edit').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId = li.data("item-id")
      const item = this.actor.items.get( itemId )
      item.sheet.render(true)
    })      
    // Delete Inventory Item
    html.find('.item-delete').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      HeritiersUtility.confirmDelete(this, li);
    })
    html.find('.edit-item-data').change(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId    = li.data("item-id")
      let itemType  = li.data("item-type")
      let itemField = $(ev.currentTarget).data("item-field")
      let dataType = $(ev.currentTarget).data("dtype")
      let value = ev.currentTarget.value
      this.actor.editItemField(itemId, itemType, itemField, dataType, value)
    })

    html.find('.adversite-modify').click(event => {
      const li = $(event.currentTarget).parents(".item")
      let adv = li.data("adversite")
      let value = Number($(event.currentTarget).data("adversite-value"))
      this.actor.incDecAdversite(adv, value)
    })
    
    html.find('.quantity-modify').click(event => {
      const li = $(event.currentTarget).parents(".item")
      const value = Number($(event.currentTarget).data("quantite-value"))
      this.actor.incDecQuantity( li.data("item-id"), value );
    })

    html.find('.roll-initiative').click((event) => {
      this.actor.rollAttribut("pre", true)
    })
    
    html.find('.roll-attribut').click((event) => {
      const li = $(event.currentTarget).parents(".item")
      let attrKey = li.data("attr-key")
      this.actor.rollAttribut(attrKey, false)
    })
    html.find('.roll-competence').click((event) => {
      const li = $(event.currentTarget).parents(".item")
      let attrKey = $(event.currentTarget).data("attr-key")
      let compId  = li.data("item-id")
      this.actor.rollCompetence(attrKey, compId)
    })
    html.find('.roll-arme-offensif').click((event) => {
      const li = $(event.currentTarget).parents(".item")
      let armeId  = li.data("item-id")
      this.actor.rollArmeOffensif(armeId)
    })
    html.find('.roll-arme-degats').click((event) => {
      const li = $(event.currentTarget).parents(".item")
      let armeId  = li.data("item-id")
      this.actor.rollArmeDegats(armeId)
    })
    
    html.find('.item-add').click((event) => {
      const itemType = $(event.currentTarget).data("type")
      this.actor.createEmbeddedDocuments('Item', [{ name: `Nouveau ${itemType}`, type: itemType }], { renderSheet: true })
    })
    
    html.find('.lock-unlock-sheet').click((event) => {
      this.options.editScore = !this.options.editScore;
      this.render(true);
    });    
    html.find('.item-equip').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      this.actor.equipItem( li.data("item-id") );
      this.render(true);      
    });

  }
  
  /* -------------------------------------------- */
  /** @override */
  setPosition(options = {}) {
    const position = super.setPosition(options);
    const sheetBody = this.element.find(".sheet-body");
    const bodyHeight = position.height - 192;
    sheetBody.css("height", bodyHeight);
    return position;
  }

  /* -------------------------------------------- */
  async _onDropItem(event, dragData) {
    let data = event.dataTransfer.getData('text/plain')
    let dataItem = JSON.parse( data)
    let item = fromUuidSync(dataItem.uuid)
    if (item.pack) {
      item = await HeritiersUtility.searchItem(item)
    }
    let autoresult = HeritiersAutomation.processAutomations("on-drop", item, this.actor)
    if (  autoresult.isValid ) {
      super._onDropItem(event, dragData)
    } else {
      ui.notifications.warn( autoresult.warningMessage)
    }
  }

}

==> fvtt-les-heritiers-10.0.29.tar.gz: fvtt-les-heritiers/modules/heritiers-actor-sheet.js <==
/**
 * Extend the basic ActorSheet with some very simple modifications
 * @extends {ActorSheet}
 */

import { HeritiersUtility } from "./heritiers-utility.js";

/* -------------------------------------------- */
export class HeritiersActorSheet extends ActorSheet {

  /** @override */
  static get defaultOptions() {

    return mergeObject(super.defaultOptions, {
      classes: ["fvtt-les-heritiers", "sheet", "actor"],
      template: "systems/fvtt-les-heritiers/templates/actor-sheet.html",
      width: 780,
      height: 840,
      tabs: [{ navSelector: ".sheet-tabs", contentSelector: ".sheet-body", initial: "stats" }],
      dragDrop: [{ dragSelector: ".item-list .item", dropSelector: null }],
      editScore: false
    })
  }

  /* -------------------------------------------- */
  async getData() {
    const objectData = duplicate(this.object)    

    let formData = {
      title: this.title,
      id: objectData.id,
      type: objectData.type,
      img: objectData.img,
      name: objectData.name,
      editable: this.isEditable,
      cssClass: this.isEditable ? "editable" : "locked",
      system: objectData.system,
      effects: this.object.effects.map(e => foundry.utils.deepClone(e.data)),
      limited: this.object.limited,
      skills: this.actor.getSkills(),
      utileSkillsMental :this.actor.organizeUtileSkills("mental"),
      utileSkillsPhysical :this.actor.organizeUtileSkills("physical"),
      futileSkills :this.actor.organizeFutileSkills(),
      contacts: this.actor.organizeContacts(),
      armes: duplicate(this.actor.getWeapons()),
      monnaies: duplicate(this.actor.getMonnaies()),
      pouvoirs: duplicate(this.actor.getPouvoirs()),
      fee: duplicate(this.actor.getFee() || {} ),
      protections: duplicate(this.actor.getArmors()),
      combat: this.actor.getCombatValues(),      
      equipements: duplicate(this.actor.getEquipments()),
      avantages: duplicate(this.actor.getAvantages()),
      atouts: duplicate(this.actor.getAtouts()),
      capacites: duplicate(this.actor.getCapacites()),
      desavantages: duplicate(this.actor.getDesavantages()),
      profils: duplicate(this.actor.getProfils()),
      pvMalus: this.actor.getPvMalus(),      
      initiative: this.actor.getFlag("world", "last-initiative") || -1,
      description: await TextEditor.enrichHTML(this.object.system.biodata.description, {async: true}),
      revesetranges: await TextEditor.enrichHTML(this.object.system.biodata.revesetranges, {async: true}),
      secretsdecouverts: await TextEditor.enrichHTML(this.object.system.biodata.secretsdecouverts, {async: true}),
      questions: await TextEditor.enrichHTML(this.object.system.biodata.questions, {async: true}),
      habitat: await TextEditor.enrichHTML(this.object.system.biodata.habitat, {async: true}),
      options: this.options,
      owner: this.document.isOwner,
      editScore: this.options.editScore,
      isGM: game.user.isGM,
      isPNJ: (this.actor.type == "pnj")
    }
    this.formData = formData;

    console.log("PC : ", formData, this.object);
    return formData;
  }

  /* -------------------------------------------- */
  getCelluleTalents( )  {
    let talents = []
    for(let cellule of game.actors) {
      if (cellule.type == "cellule") {
        let found = cellule.system.members.find( it => it.id == this.actor.id)
        if (found) {
          talents = talents.concat( cellule.getTalents() )
        }
      }
    }
    return talents
  }

  /* -------------------------------------------- */
  /** @override */
  activateListeners(html) {
    super.activateListeners(html);

    // Everything below here is only needed if the sheet is editable
    if (!this.options.editable) return;
    
    // Update Inventory Item
    html.find('.item-edit').click(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId = li.data("item-id")
      const item = this.actor.items.get( itemId )
      item.sheet.render(true)
    })      
    // Delete Inventory Item
    html.find('.item-delete').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      HeritiersUtility.confirmDelete(this, li);
    })
    html.find('.edit-item-data').change(ev => {
      const li = $(ev.currentTarget).parents(".item")
      let itemId    = li.data("item-id")
      let itemType  = li.data("item-type")
      let itemField = $(ev.currentTarget).data("item-field")
      let dataType = $(ev.currentTarget).data("dtype")
      let value = ev.currentTarget.value
      this.actor.editItemField(itemId, itemType, itemField, dataType, value)
    })

    html.find('.adversite-modify').click(event => {
      const li = $(event.currentTarget).parents(".item")
      let adv = li.data("adversite")
      let value = Number($(event.currentTarget).data("adversite-value"))
      this.actor.incDecAdversite(adv, value)
    })
    
    html.find('.quantity-modify').click(event => {
      const li = $(event.currentTarget).parents(".item")
      const value = Number($(event.currentTarget).data("quantite-value"))
      this.actor.incDecQuantity( li.data("item-id"), value );
    })

    html.find('.roll-initiative').click((event) => {
      this.actor.rollInitiative()
    })
    
    html.find('.roll-carac').click((event) => {
      const key = $(event.currentTarget).data("key")
      this.actor.rollCarac(key, false)
    })
    html.find('.roll-rang').click((event) => {
      const key = $(event.currentTarget).data("rang-key")
      this.actor.rollRang(key, false)
    })    
    html.find('.roll-root-competence').click((event) => {
      const compKey = $(event.currentTarget).data("attr-key")
      this.actor.rollRootCompetence(compKey)
    })
    html.find('.roll-competence').click((event) => {
      const li = $(event.currentTarget).parents(".item")
      let compId  = li.data("item-id")
      this.actor.rollCompetence(compId)
    })
    html.find('.roll-attaque-arme').click((event) => {
      const li = $(event.currentTarget).parents(".item")
      let armeId  = li.data("item-id")
      this.actor.rollAttaqueArme(armeId)
    })
    html.find('.roll-pouvoir').click((event) => {
      const li = $(event.currentTarget).parents(".item")
      let pouvoirId = li.data("item-id")
      this.actor.rollPouvoir(pouvoirId)
    })
    
    html.find('.item-add').click((event) => {
      const itemType = $(event.currentTarget).data("type")
      this.actor.createEmbeddedDocuments('Item', [{ name: `Nouveau ${itemType}`, type: itemType }], { renderSheet: true })
    })
    
    html.find('.lock-unlock-sheet').click((event) => {
      this.options.editScore = !this.options.editScore;
      this.render(true);
    });    
    html.find('.item-equip').click(ev => {
      const li = $(ev.currentTarget).parents(".item");
      this.actor.equipItem( li.data("item-id") );
      this.render(true);      
    });

  }
  
  /* -------------------------------------------- */
  /** @override */
  setPosition(options = {}) {
    const position = super.setPosition(options);
    const sheetBody = this.element.find(".sheet-body");
    const bodyHeight = position.height - 192;
    sheetBody.css("height", bodyHeight);
    return position;
  }

  /* -------------------------------------------- */
  /*async _onDropItem(event, dragData) {
    let data = event.dataTransfer.getData('text/plain')
    let dataItem = JSON.parse( data)
    let item = fromUuidSync(dataItem.uuid)
    if (item.pack) {
      item = await HeritiersUtility.searchItem(item)
    }
    super._onDropItem(event, dragData)
  }*/

}
